@@ -8,3 +8,5 @@ from .google_set import GoogleSet
 from .ibmq_set import IBMQSet
 from .ionq_set import IonQSet
 from .ustc_set import USTCSet
+from .nam_set import NamSet
+from .origin_set import OriginSet
