@@ -2,5 +2,5 @@ from .cpu_simulator import CircuitSimulator
 
 try:
     from .gpu_simulator import ConstantStateVectorSimulator
-except ModuleNotFoundError:
+except Exception as e:
     pass
